#!/bin/bash
path="trunk"
target="InHouse_Staging"
workspace="$WORKSPACE"

set -- $(getopt e: "$@")
while [ $# -gt 0 ]
do
    case "$1" in
    p) path="$2"; shift;;
 	t) target="$2"; shift;;
	w) workspace=`pwd`; shift;;
    esac
    shift
done

echo "path=$path";
echo "target=$target";
echo "workspace=$workspace";



export PROJECT="NikePlus"
export LOCAL_DEPLOYMENT_PATH="$workspace/deployment"


##########################
#So Hudson Knows we Failed
##########################
function failed(){
    echo "Failed : $@" >&2
    exit 1
}


##################################
# Clean stuff from previous builds
##################################
rm -rf $LOCAL_DEPLOYMENT_PATH/*

##################
# Make the build
##################
echo "**** Running XCode Build ****"
cd $workspace/$path/

xcodebuild build -target $PROJECT -configuration $target clean

xcodebuild build -target $PROJECT -configuration $target || failed

#################
# Create the IPA
#################
echo "**** Creating the IPA ****"


cd $workspace/$path/build/$target-iphoneos
mkdir Payload
cp -r *.app Payload
zip -r NikePlus.ipa Payload || failed zip_payload
#rm -rf Payload
#zip -r dSYM-$SVN_REVISION.zip *.dSYM || failed zip_dysm

#############################
# Copy over all the artifacts
#############################
echo "copying ipa and dsyms to deployment path: $LOCAL_DEPLOYMENT_PATH"
mkdir $LOCAL_DEPLOYMENT_PATH
cp NikePlus.ipa $LOCAL_DEPLOYMENT_PATH || failed copy_ipa
zip -r dSYM.zip *.dSYM || failed zip_dysm
cp dSYM.zip $LOCAL_DEPLOYMENT_PATH || failed copy_dsym_zip

############################
# Upload to TestFlight
############################
#API_TOKEN=974ea8ff343e712b664e480f55130dc4_OTQzNjM
#TEAM_TOKEN=741f8993ff6920770ca4b11ce36364e8_Mjk2NjgyMDExLTA5LTE2IDE4OjUxOjUxLjY5NTc4MA
API_TOKEN=974ea8ff343e712b664e480f55130dc4_OTQzNjM
TEAM_TOKEN=1520c8b8d0f1560f2f63ade7b908fd7c_Mjk3MjcyMDExLTA5LTE3IDExOjE3OjA1LjAyNzg4Mw
echo "uploading to TestFlight using API_TOKEN: $API_TOKEN ..."

export NOTES="Path: $path. Target: $target.\nBuild number: $BUILD_NUMBER. Build id: $BUILD_ID. Job name: $JOB_NAME"

curl http://testflightapp.com/api/builds.json \
  -F file=@$workspace/$path/build/$target-iphoneos/NikePlus.ipa \
  -F api_token=$API_TOKEN \
  -F team_token=$TEAM_TOKEN \
  -F notes="$NOTES" \
  -F notify=True \
  -F distribution_lists='Internal QA'

echo "Finished!"

###################
# Run Beta Builder
##################
#echo "**** Running Beta Builder ****"
#export BUNDLEID="com.nike.nikeplus-inhouse"
#python $BETABUILDER --destination=$LOCAL_DEPLOYMENT_PATH/$SVN_REVISION --ipafile=$LOCAL_DEPLOYMENT_PATH/$SVN_REVISION/NikePlus_r$SVN_REVISION.ipa --appname="nikeplus_gps" --server="$DEPLOYMENT_PATH/hudson-$BUILD_NUMBER-revision-$SVN_REVISION/" --bundle=$BUNDLEID --version=1.0 || failed betabuilder

#cd $LOCAL_DEPLOYMENT_PATH
#sed s#%%URL%%#$DEPLOYMENT_PATH/hudson-$BUILD_NUMBER-revision-$SVN_REVISION/# $WORKSPACE/trunk/hudson/link_to_build.html > ./link_to_build.html

#echo "**** Checkout the build at $DEPLOYMENT_PATH/hudson-$BUILD_NUMBER-revision-$SVN_REVISION/"
