#!/usr/bin/env python
# encoding: utf-8
"""
diffLanguages.py

Created by Anderson Miller on 2010-11-03.
Copyright (c) 2010 R/GA. All rights reserved.
"""

import sys
import os
import codecs
import pickle

class Language:
	def __init__(self):
		self.entities = list()
		
	def __init__(self,fd):
		self.entities = list()
		self.fromFile(fd)
			
	def fromFile(self,fileDescriptor):
		temp = LocalizableEntity()
		try:
			for line in fileDescriptor:
				if( not isKeyValuePair(line) ):
					temp.comments += line
				else:
					temp.makeFromString(line)
					self.add(temp)
					temp = LocalizableEntity()
		finally:
			fileDescriptor.close()
		
		
	
	def add(self,entity):
		self.entities.append(entity)
	
	def size(self):
		return len(self.entities)
		
	def untranslated(self):
		i = 0
		for item in self.entities:
			if(item.untranslated()):
				i+=1
		return i

class LocalizableEntity:
	def __init__(self):
		self.key = ""
		self.value = ""
		self.comments = ""

	def render(self):
		print self.comments
		print self.key
		print repr(self.value)

	def makeFromString(self,string):
		two = string.split('=')
		self.key = "%s" % two[0].strip()
		#print self.key
		#print self.key
		self.value = two[1].strip()


	def untranslated(self):
		if( self.key == self.value ):
			return True
		return False
		
	def equals(self,otherentity):
		#if(self.key == otherentity.key):
		#	return True
		#if(self.key != otherentity.key):\
		if(len(self.key) == len(otherentity.key)):
			print "self.key: %d %s and otherentity.key:%d  %s" % (len(self.key),self.key,len(otherentity.key),otherentity.key)
		return False

def isKeyValuePair(string):
	temp = string.count('\"')
	temp += string.count('=')
	#print temp
	
	temp1 = string.count('//\"')
	if(temp1 > 0):
		return False
		
	if(temp > 4):
		return True
	return False
	


def diffTwoLanguages( lang1, lang2 ):
	same = 0
	diff = list()
	for item in lang1.entities:
		found = False
		for item1 in lang2.entities:
			if( item.key == item1.key):
				same += 1
				found=True
		if(not found):
			diff.append(item)
	print same
	return diff

def main():
	fa = codecs.open('../localization/Localizable.strings',encoding='utf-16')
	fb = codecs.open('../localization/ja.lproj/Localizable.strings',encoding='utf-16')
	fc = codecs.open("../localization/de.lproj/Localizable.strings",encoding='utf-16')
	fd = codecs.open("../localization/es.lproj/Localizable.strings",encoding='utf-8')
	fe = codecs.open("../localization/fr.lproj/Localizable.strings",encoding='utf-8')
	ff = codecs.open("../localization/it.lproj/Localizable.strings",encoding='utf-8')
	fg = codecs.open("../localization/pt.lproj/Localizable.strings",encoding='utf-8')
	fh = codecs.open("../localization/zh-Hans.lproj/Localizable.strings",encoding='utf-16')
	fi = codecs.open("../localization/zh-Hant.lproj/Localizable.strings",encoding='utf-16')
	
	english = Language(fa)
	japanese = Language(fb)
	german = Language(fc)
	french = Language(fe)
	italian = Language(ff)
	portugese = Language(fg)
	spanish = Language(fd)
	
	print english.size()
	print japanese.size()
	print german.size()
	print italian.size()
	print portugese.size()
	print spanish.size()
	
	
	diff1 = diffTwoLanguages(english,japanese)
	diff2 = diffTwoLanguages(english,german)
	diff3 = diffTwoLanguages(english,italian)
	diff4 = diffTwoLanguages(english,portugese)
	diff5 = diffTwoLanguages(english,spanish)
	
	print "items found in english and not in japanese: %d" % len(diff1)
	print "items found in english and not in german: %d" % len(diff2)
	print "items found in english and not in italian: %d" % len(diff3)
	print "items found in english and not in portugese: %d" % len(diff4)
	print "items found in english and not in spanish: %d" % len(diff5)
	
	print "the number untranslated in italian is %d" % italian.untranslated()
	print "the number untranslated in german is %d" % german.untranslated()
	
	
	pass


if __name__ == '__main__':
	main()

